=================
reStructuredText
=================

.. vb:function:: Private Function getId(ByVal name As String, ByVal age As Integer) As Integer
   :module: reST

   かんたんなプライベート関数

   :param name: 名前
   :type name: String
   :param age: 年齢
   :type age: Integer
   :returns: id
   :rtype: Integer

   ここに remarks を書く。

.. vb:function:: Private Function getId(ByVal name As String, ByVal age As Integer) As Integer
   :module: 日本語のモジュール名

   かんたんなプライベート関数

   :param name: 名前
   :type name: String
   :param age: 年齢
   :type age: Integer
   :returns: id
   :rtype: Integer

   ここに remarks を書く。

.. vb:function:: Sub なんらかの処理(ByVal name As String, ByVal age As Integer)
   :module: 日本語のモジュール名

   関数名がすべて日本語

   :param name: 名前
   :type name: String
   :param age: 年齢
   :type age: Integer

Cross-references
----------------

* :any:`module1.sampleprocedure`
* これは :any:`関数へのリンク <module1.sampleprocedure>` です。
* :vb:function:`cd94f36.sampleprocedure`
* :vb:function:`関数へのリンク <cd94f36.sampleprocedure>`

.. * :vb:function:`module1.sampleprocedure`
